@@ -62,6 +62,8 @@ import PluginRender from './PluginRender';
 import HighlightText from './HighlightText';
 import CardBadge from './CardBadge';
 import PinList from './PinList';
+import MobileSideNav from './MobileSideNav';
+import AdminSideNav from './AdminSideNav';
 
 export {
   Avatar,
@@ -111,5 +113,7 @@ export {
   HighlightText,
   CardBadge,
   PinList,
+  MobileSideNav,
+  AdminSideNav,
 };
 export type { EditorRef, JSONSchema, UISchema };
